pub struct Normalizer { /* private fields */ }Expand description
SentencePiece-compatible normalizer.
It supports the model flags used by the runtime and the precompiled normalization trie embedded in standard SentencePiece model files.
Implementations